import React from 'react';
import { EventData } from 'vanilla-swipe';
import Link, { type LinkProps } from './views/Link';
import { AnimationType, AutoplayDirection, EventObject, EventType, Props, SlideTo, State } from './types';
export * from './types';
export { Link, type LinkProps };
export default class AliceCarousel extends React.PureComponent<Props, State> {
    static defaultProps: {
        activeIndex: number;
        animationDuration: number;
        animationEasingFunction: string;
        animationType: AnimationType;
        autoHeight: boolean;
        autoWidth: boolean;
        autoPlay: boolean;
        autoPlayControls: boolean;
        autoPlayDirection: AutoplayDirection;
        autoPlayInterval: number;
        autoPlayStrategy: import("./types").AutoPlayStrategy;
        children: undefined;
        controlsStrategy: import("./types").ControlsStrategy;
        disableButtonsControls: boolean;
        disableDotsControls: boolean;
        disableSlideInfo: boolean;
        infinite: boolean;
        innerWidth: undefined;
        items: undefined;
        keyboardNavigation: boolean;
        mouseTracking: boolean;
        syncStateOnPropsUpdate: boolean;
        name: string;
        paddingLeft: number;
        paddingRight: number;
        responsive: undefined;
        swipeDelta: number;
        swipeExtraPadding: number;
        ssrSilentMode: boolean;
        touchTracking: boolean;
        touchMoveDefaultEvents: boolean;
        onInitialized: () => undefined;
        onResized: () => undefined;
        onUpdated: () => undefined;
        onResizeEvent: undefined;
        onSlideChange: () => undefined;
        onSlideChanged: () => undefined;
    };
    private autoPlayTimeoutId?;
    private slideEndTimeoutId?;
    private touchEndTimeoutId?;
    private isAnimationDisabled;
    private isHovered;
    private isTouchMoveProcessStarted;
    private cancelTouchAnimations;
    private hasUserAction;
    private rootElement;
    private rootComponentDimensions;
    private stageComponent;
    private startTouchmovePosition;
    private swipeListener;
    private _handleResizeDebounced;
    private _cancelResizeDebounced;
    constructor(props: Props);
    componentDidMount(): Promise<void>;
    componentDidUpdate(prevProps: Readonly<Props>): void;
    componentWillUnmount(): void;
    get eventObject(): EventObject;
    get isFadeoutAnimationAllowed(): boolean;
    get touchmovePosition(): number;
    slideTo(activeIndex?: number, eventType?: EventType): void;
    slidePrev(e?: Event | React.MouseEvent): void;
    slideNext(e?: Event | React.MouseEvent): void;
    _addEventListeners(): void;
    _removeEventListeners(): void;
    _updateEventListeners(): void;
    _handleKeyboardEvents: (e: Event & {
        code: string;
    }) => false | void | Promise<void>;
    _handleResize(e: Event): Promise<void>;
    _handleTouchmove(e: Event, eventData: EventData): void;
    _handleTouchend(e: Event, { deltaX }: EventData): void;
    _handleBeforeTouchEnd(position: number): void;
    _handleSlideTo({ activeIndex, fadeoutAnimationIndex, fadeoutAnimationPosition, eventType, }: SlideTo): Promise<void>;
    _handleBeforeSlideEnd: (eventType?: EventType) => Promise<void>;
    _handleUpdateSlidePosition(activeIndex: number): Promise<void>;
    _handleUpdated(): void;
    _handleResized(e?: Partial<EventObject>): void;
    _handleSlideChange(eventType?: EventType): void;
    _handleSlideChanged(eventType?: EventType): Promise<void>;
    _handleDotClick(index: number): void;
    _handleMouseEnter: () => void;
    _handleMouseLeave: () => void;
    _handlePlay(): void;
    _handlePause: () => void;
    _handlePlayPauseToggle: () => Promise<void>;
    _cancelTimeoutAnimations(): void;
    _clearAutoPlayTimeout(): void;
    _clearSlideEndTimeout(): void;
    clearTouchendTimeout(): void;
    _clearTouchmovePosition(): void;
    _setTouchmovePosition(): void;
    _setRootComponentRef: (node: HTMLDivElement) => HTMLDivElement;
    _setStageComponentRef: (node: HTMLUListElement) => HTMLUListElement;
    _setInitialState(): Promise<void>;
    _setAutoPlayInterval(): void;
    _setupSwipeHandlers(): void;
    _updateComponent(): void;
    _updateSwipeProps(): void;
    _renderStageItem: (item: React.ReactNode, i: number) => JSX.Element;
    _renderSlideInfo: () => JSX.Element;
    _renderDotsNavigation(): JSX.Element;
    _renderPrevButton(): JSX.Element;
    _renderNextButton(): JSX.Element;
    _renderPlayPauseButton(): JSX.Element;
    render(): JSX.Element;
}
